
/*
 * Example for MCP1664 click
 *
 * Date         Apr 2017
 * Author       Danilo Milovic
 *
 * Test configuration dsPIC :
 *  MCU           :        P32MX795512L
 *  Dev. Board    :        EasyPIC Fusion v7
 *  SW            :        mikroC PRO for dsPIC v7.0.1
 *
 * Description :
 *
 * This example shows basic control of light brightness with PWM,
 * duty cycle is controled with potentiometer P1, jumper J8 needs to be set on B0
 * CAUTION: Do not look directly at LED's.
 ******************************************************************************/
 #include <stdint.h>
  uint16_t current_duty;
  uint16_t pwm_period1;
  uint16_t adc_result;
  char txt[12];



  void MCU_Init()
  {
    TRISB0_bit = 1;                      //configure PORTB pin 0 as input
    TRISD0_bit = 0;                      //configure PORTC pin 1 as output (PWM)
    JTAGEN_bit = 0;

    ADC1_Init();                         // ADC Init
    Delay_ms(100);
    current_duty = 0;                    // initial value for current duty

    PWM_Init(5000 , 1, 1, 2);            // PWM Initialization
    PWM_Start(1);
    PWM_Set_Duty(current_duty,  1);      // Set current duty for PWM1
   }





  void main()
  {
    MCU_Init();


    while( 1 )
    {
      uint16_t cur_duty_byte;

      // Read 10 - bit ADC value and set newly acquired 8 - bit PWM duty
      adc_result = ADC1_Read(0);
      current_duty = adc_result;
      PWM_Set_Duty(adc_result * 16, 1);       // Set newly acquired duty

      Delay_ms(20);
    }
  }